@@ -1,21 +1,18 @@
 import base64
 import json
 import time
-import urllib
-import urllib2
+import urllib.request
 
-"""
-The mixpanel package allows you to easily track events and
-update people properties from your python application.
+# The mixpanel package allows you to easily track events and
+# update people properties from your python application.
+#
+# The Mixpanel class is the primary class for tracking events and
+# sending people analytics updates.
+#
+# The Consumer and BufferedConsumer classes allow callers to
+# customize the IO characteristics of their tracking.
 
-The Mixpanel class is the primary class for tracking events and
-sending people analytics updates.
-
-The Consumer and BufferedConsumer classes allow callers to
-customize the IO characteristics of their tracking.
-"""
-
-VERSION = '3.2.0'
+VERSION = '3.0.0'
 
 
 class Mixpanel(object):
@@ -73,72 +70,21 @@ class Mixpanel(object):
         event.update(meta)
         self._consumer.send('events', json.dumps(event, separators=(',', ':')))
 
-    def import_data(self, api_key, distinct_id, event_name, timestamp, properties={}, meta={}):
-        """
-        Allows data older than 5 days old to be sent to MixPanel.
-
-        API Notes:
-        https://mixpanel.com/docs/api-documentation/importing-events-older-than-31-days
-
-        Usage:
-        import datetime
-        from your_app.conf import YOUR_MIXPANEL_TOKEN, YOUR_MIXPANEL_API_KEY
-
-        mp = MixPanel(YOUR_TOKEN)
-
-        # Django queryset to get an old event
-        old_event = SomeEvent.objects.get(create_date__lt=datetime.datetime.now() - datetime.timedelta.days(6))
-        mp.import_data(
-            YOUR_MIXPANEL_API_KEY,  # These requests require your API key as an extra layer of security
-            old_event.id,
-            'Some Event',
-            old_event.timestamp,
-            {
-                ... your custom properties and meta ...
-            }
-        )
-        """
-        all_properties = {
-            'token': self._token,
-            'distinct_id': distinct_id,
-            'time': int(timestamp),
-            'mp_lib': 'python',
-            '$lib_version': VERSION,
-        }
-        all_properties.update(properties)
-        event = {
-            'event': event_name,
-            'properties': all_properties,
-        }
-        event.update(meta)
-        self._consumer.send('imports', json.dumps(event, separators=(',', ':')), api_key)
-
     def alias(self, alias_id, original, meta={}):
         """
         Gives custom alias to a people record.
 
-        Calling this method always results in a synchronous HTTP
-        request to Mixpanel servers. Unlike other methods, this method
-        will ignore any consumer object provided to the Mixpanel
-        object on construction.
-
         Alias sends an update to our servers linking an existing distinct_id
         with a new id, so that events and profile updates associated with the
         new id will be associated with the existing user's profile and behavior.
         Example:
             mp.alias('amy@mixpanel.com', '13793')
         """
-        sync_consumer = Consumer()
-        event = {
-            'event': '$create_alias',
-            'properties': {
-                'distinct_id': original,
-                'alias': alias_id,
-                'token': self._token,
-            },
-        }
-        event.update(meta)
-        sync_consumer.send('events', json.dumps(event, separators=(',', ':')))
+        self.track(original, '$create_alias', {
+            'distinct_id': original,
+            'alias': alias_id,
+            'token': self._token,
+        }, meta=meta)
 
     def people_set(self, distinct_id, properties, meta={}):
         """
@@ -194,7 +140,7 @@ class Mixpanel(object):
         property that doesn't exist will result in assigning a list with one
         element to that property.
         Example:
-            mp.people_append('12345', { "Power Ups": "Bubble Lead" })
+            mp.people_append('12345', {"Power Ups": "Bubble Lead"})
         """
         return self.people_update({
             '$distinct_id': distinct_id,
@@ -209,7 +155,7 @@ class Mixpanel(object):
         the request are merged with the existing list on the user profile,
         ignoring duplicate list values.
         Example:
-            mp.people_union('12345', { "Items purchased": ["socks", "shirts"] } )
+            mp.people_union('12345', {"Items purchased": ["socks", "shirts"]})
         """
         return self.people_update({
             '$distinct_id': distinct_id,
@@ -259,7 +205,8 @@ class Mixpanel(object):
             mp.people_track_charge('1234', 50, {'$time': "2013-04-01T09:02:00"})
         """
         properties.update({'$amount': amount})
-        return self.people_append(distinct_id, {'$transactions': properties}, meta=meta)
+        return self.people_append(distinct_id, {'$transactions': properties},
+                                  meta=meta)
 
     def people_clear_charges(self, distinct_id, meta={}):
         """
@@ -275,7 +222,6 @@ class Mixpanel(object):
     def people_update(self, message, meta={}):
         """
         Send a generic update to Mixpanel people analytics.
-
         Caller is responsible for formatting the update message, as
         documented in the Mixpanel HTTP specification, and passing
         the message as a dict to update. This
@@ -308,15 +254,13 @@ class Consumer(object):
     with one request for every call. This is the default consumer for Mixpanel
     objects- if you don't provide your own, you get one of these.
     """
-    def __init__(self, events_url=None, people_url=None, import_url=None, request_timeout=None):
+    def __init__(self, events_url=None, people_url=None):
         self._endpoints = {
             'events': events_url or 'https://api.mixpanel.com/track',
             'people': people_url or 'https://api.mixpanel.com/engage',
-            'imports': import_url or 'https://api.mixpanel.com/import',
         }
-        self._request_timeout = request_timeout
 
-    def send(self, endpoint, json_message, api_key=None):
+    def send(self, endpoint, json_message):
         """
         Record an event or a profile update. Send is the only method
         associated with consumers. Will raise an exception if the endpoint
@@ -333,29 +277,21 @@ class Consumer(object):
         :raises: MixpanelException
         """
         if endpoint in self._endpoints:
-            self._write_request(self._endpoints[endpoint], json_message, api_key)
+            self._write_request(self._endpoints[endpoint], json_message)
         else:
             raise MixpanelException('No such endpoint "{0}". Valid endpoints are one of {1}'.format(self._endpoints.keys()))
 
-    def _write_request(self, request_url, json_message, api_key=None):
-        data = {
-            'data': base64.b64encode(json_message),
+    def _write_request(self, request_url, json_message):
+        data = urllib.parse.urlencode({
+            'data': base64.b64encode(json_message.encode('utf-8')),
             'verbose': 1,
-            'ip': 0,
-        }
-        if api_key:
-            data.update({'api_key': api_key})
-        encoded_data = urllib.urlencode(data)
+            'ip': 0
+        }).encode('utf-8')
         try:
-            request = urllib2.Request(request_url, encoded_data)
-
-            # Note: We don't send timeout=None here, because the timeout in urllib2 defaults to
-            # an internal socket timeout, not None.
-            if self._request_timeout is not None:
-                response = urllib2.urlopen(request, timeout=self._request_timeout).read()
-            else:
-                response = urllib2.urlopen(request).read()
-        except urllib2.HTTPError as e:
+            req = urllib.request.Request(url=request_url, data=data, method='POST')
+            f = urllib.request.urlopen(req)
+            response = f.read().decode('utf-8')
+        except urllib.error.HTTPError as e:
             raise MixpanelException(e)
 
         try:
@@ -379,12 +315,11 @@ class BufferedConsumer(object):
     when you're sure you're done sending them. calls to flush() will
     send all remaining unsent events being held by the BufferedConsumer.
     """
-    def __init__(self, max_size=50, events_url=None, people_url=None, request_timeout=None):
-        self._consumer = Consumer(events_url, people_url, request_timeout)
+    def __init__(self, max_size=50, events_url=None, people_url=None):
+        self._consumer = Consumer(events_url, people_url)
         self._buffers = {
             'events': [],
             'people': [],
-            'imports': [],
         }
         self._max_size = min(50, max_size)
 
@@ -395,10 +330,12 @@ class BufferedConsumer(object):
         may trigger a request to Mixpanel's servers.
 
         Calls to send() may throw an exception, but the exception may be
-        associated with the message given in an earlier call. If this is the case,
-        the resulting MixpanelException e will have members e.message and e.endpoint
+        associated with the message given in an earlier call. If this is the
+        case, the resulting MixpanelException e will have members e.message
+        and e.endpoint
 
-        :param endpoint: One of 'events' or 'people', the Mixpanel endpoint for sending the data
+        :param endpoint: One of 'events' or 'people', the Mixpanel endpoint
+            for sending the data
         :type endpoint: str (one of 'events' or 'people')
         :param json_message: A json message formatted for the endpoint.
         :type json_message: str
@@ -414,12 +351,11 @@ class BufferedConsumer(object):
 
     def flush(self):
         """
-        Send all remaining messages to Mixpanel.
-
-        BufferedConsumers will flush automatically when you call send(), but
-        you will need to call flush() when you are completely done using the
-        consumer (for example, when your application exits) to ensure there are
-        no messages remaining in memory.
+        Send all remaining messages to Mixpanel. BufferedConsumers will
+        flush automatically when you call send(), but you will need to call
+        flush() when you are completely done using the consumer (for example,
+        when your application exits) to ensure there are no messages remaining
+        in memory.
 
         Calls to flush() may raise a MixpanelException if there is a problem
         communicating with the Mixpanel servers. In this case, the exception
